@@ -1,14 +1,15 @@
 package Net::DNS::RR::MX;
-
-# $Id: MX.pm,v 1.3 2002/05/22 18:09:36 ctriv Exp $
-
+#
+# $Id: MX.pm,v 1.4 2003/08/26 23:58:10 ctriv Exp $
+#
 use strict;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 
 use Net::DNS;
 use Net::DNS::Packet;
 
-@ISA = qw(Net::DNS::RR);
+@ISA     = qw(Net::DNS::RR);
+$VERSION = (qw$Revision: 1.4 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
